/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */

#include "BITMAPS/Line0pt.xbm"
#include "BITMAPS/Line1pt.xbm"
#include "BITMAPS/Line2pt.xbm"
#include "BITMAPS/Line3pt.xbm"
#include "BITMAPS/Line4pt.xbm"
#include "BITMAPS/Line5pt.xbm"
#include "BITMAPS/LineSol.xbm"
#include "BITMAPS/LineDot.xbm"
#include "BITMAPS/LineDas.xbm"
#include "BITMAPS/Box.xbm"
#include "BITMAPS/Tri.xbm"
#include "BITMAPS/Point.xbm"
#include "BITMAPS/Plus.xbm"
#include "BITMAPS/Cross.xbm"
#include "BITMAPS/Circle.xbm"
#include "BITMAPS/FillBox.xbm"
#include "BITMAPS/FillTri.xbm"
#include "BITMAPS/FillCircle.xbm"
#include "BITMAPS/Sphere.xbm"
